@@ -1,4 +1,4 @@
-from wxc_sdk.base import ApiModel, StrOrDict, to_camel, webex_id_to_uuid
+from wxc_sdk.base import ApiModel, ApiModelWithErrors, CodeAndReason, StrOrDict, to_camel, webex_id_to_uuid
 from wxc_sdk.common import AlternateNumber, AuthCode, CallParkExtension, Greeting, MonitoredMember,\
     PersonPlaceAgent, RingPattern, UserBase, UserNumber, UserType
 from wxc_sdk.common.schedules import Event, RecurWeekly, RecurYearlyByDate, RecurYearlyByDay, Recurrence,\
@@ -66,42 +66,43 @@ from wxc_sdk.webhook import WebHook, WebHookCreate, WebHookEvent, WebHookResourc
 from wxc_sdk.workspaces import Calendar, CalendarType, CallingType, WorkSpaceType, Workspace, WorkspaceEmail
 
 __all__ = ['Action', 'Agent', 'AlternateNumber', 'AlternateNumberSettings', 'Announcement', 'ApiModel',
-           'AppServicesSettings', 'AudioSource', 'AuthCode', 'AutoAttendant', 'AutoAttendantAction',
-           'AutoAttendantKeyConfiguration', 'AutoAttendantMenu', 'AutoTransferNumbers', 'AvailableRecallHuntGroup',
-           'BargeSettings', 'BehaviorType', 'BlockContiguousSequences', 'BlockPreviousPasscodes',
-           'BlockRepeatedDigits', 'BusinessContinuity', 'Calendar', 'CalendarType', 'CallBounce', 'CallForwarding',
-           'CallForwardingAlways', 'CallForwardingCommon', 'CallForwardingNoAnswer', 'CallForwardingNumber',
-           'CallForwardingNumberType', 'CallForwardingPerson', 'CallHistoryRecord', 'CallInfo', 'CallPark',
-           'CallParkExtension', 'CallParkRecall', 'CallParkSettings', 'CallPickup', 'CallQueue',
-           'CallQueueCallPolicies', 'CallRecordingSetting', 'CallState', 'CallType', 'CallTypePermission', 'CallerId',
-           'CallerIdSelectedType', 'CallingBehavior', 'CallingPermissions', 'CallingType', 'CallsFrom',
-           'ComfortMessageSetting', 'CustomNumberInfo', 'CustomNumberType', 'CustomNumbers', 'DND',
-           'DefaultVoicemailPinRules', 'DialResponse', 'Dialing', 'DistinctiveRing', 'EnabledAndNumberOfDays',
-           'Event', 'ExecAssistantType', 'ExpirePasscode', 'ExternalCallerIdNamePolicy', 'ExternalTransfer',
-           'FailedAttempts', 'FeatureSelector', 'ForwardCallsTo', 'ForwardToSelection', 'ForwardingRule',
-           'ForwardingRuleDetails', 'ForwardingSetting', 'Greeting', 'Group', 'GroupMember', 'HGCallPolicies',
-           'HGandCQ', 'HistoryType', 'HuntGroup', 'IncomingPermissions', 'InterceptAnnouncements', 'InterceptNumber',
-           'InterceptSetting', 'InterceptSettingIncoming', 'InterceptSettingOutgoing', 'InterceptTypeIncoming',
-           'InterceptTypeOutgoing', 'License', 'Location', 'LocationAddress', 'LocationCallParkSettings',
-           'LocationMoHGreetingType', 'LocationMoHSetting', 'LocationVoiceMailSettings', 'MenuKey',
-           'MohMessageSetting', 'MonitoredElement', 'MonitoredElementMember', 'MonitoredMember', 'Monitoring',
-           'NetworkConnectionType', 'NoAnswer', 'Notification', 'NotificationRepeat', 'NotificationType',
-           'NumberDetails', 'NumberListPhoneNumber', 'NumberListPhoneNumberType', 'NumberLocation', 'NumberOwner',
-           'NumberState', 'NumberType', 'OrganisationVoicemailSettings', 'OrganisationVoicemailSettingsAPI',
-           'OutgoingPermissionCallType', 'OutgoingPermissions', 'OverflowAction', 'OverflowSetting', 'OwnerType',
-           'PTTConnectionType', 'Paging', 'PagingAgent', 'ParkedAgainst', 'PasscodeRules', 'PeopleStatus', 'Person',
-           'PersonForwardingSetting', 'PersonNumbers', 'PersonPhoneNumber', 'PersonPlaceAgent',
-           'PersonSettingsApiChild', 'PersonType', 'Personality', 'PhoneNumber', 'PhoneNumberType', 'PinLength',
-           'Policy', 'Privacy', 'PushToTalkAccessType', 'PushToTalkSettings', 'QueueSettings', 'Recall',
-           'RecallHuntGroup', 'ReceptionistSettings', 'Record', 'RecordingState', 'RecurWeekly', 'RecurYearlyByDate',
-           'RecurYearlyByDay', 'Recurrence', 'RedirectReason', 'Redirection', 'RejectAction', 'RingPattern',
-           'Schedule', 'ScheduleApiBase', 'ScheduleDay', 'ScheduleMonth', 'ScheduleType', 'ScheduleTypeOrStr',
-           'ScheduleWeek', 'SipAddress', 'SipType', 'SiteType', 'StorageType', 'StrOrDict', 'TelephonyCall',
-           'TelephonyEvent', 'TelephonyEventData', 'TelephonyParty', 'Tokens', 'UCMProfile', 'UnansweredCalls',
-           'UserBase', 'UserNumber', 'UserType', 'ValidateExtensionResponseStatus', 'ValidateExtensionStatus',
-           'ValidateExtensionStatusState', 'ValidateExtensionsResponse', 'VoiceMailFax', 'VoiceMailRules',
-           'VoicePortalSettings', 'VoicemailCopyOfMessage', 'VoicemailEnabled', 'VoicemailEnabledWithGreeting',
-           'VoicemailFax', 'VoicemailGroup', 'VoicemailMessageStorage', 'VoicemailNotifications', 'VoicemailSettings',
-           'VoicemailTransferToNumber', 'WaitMessageSetting', 'WaitMode', 'WebHook', 'WebHookCreate', 'WebHookEvent',
-           'WebHookResource', 'WebHookStatus', 'WelcomeMessageSetting', 'WorkSpaceType', 'Workspace',
-           'WorkspaceEmail', '_Helper', 'to_camel', 'webex_id_to_uuid']
+           'ApiModelWithErrors', 'AppServicesSettings', 'AudioSource', 'AuthCode', 'AutoAttendant',
+           'AutoAttendantAction', 'AutoAttendantKeyConfiguration', 'AutoAttendantMenu', 'AutoTransferNumbers',
+           'AvailableRecallHuntGroup', 'BargeSettings', 'BehaviorType', 'BlockContiguousSequences',
+           'BlockPreviousPasscodes', 'BlockRepeatedDigits', 'BusinessContinuity', 'Calendar', 'CalendarType',
+           'CallBounce', 'CallForwarding', 'CallForwardingAlways', 'CallForwardingCommon', 'CallForwardingNoAnswer',
+           'CallForwardingNumber', 'CallForwardingNumberType', 'CallForwardingPerson', 'CallHistoryRecord',
+           'CallInfo', 'CallPark', 'CallParkExtension', 'CallParkRecall', 'CallParkSettings', 'CallPickup',
+           'CallQueue', 'CallQueueCallPolicies', 'CallRecordingSetting', 'CallState', 'CallType',
+           'CallTypePermission', 'CallerId', 'CallerIdSelectedType', 'CallingBehavior', 'CallingPermissions',
+           'CallingType', 'CallsFrom', 'CodeAndReason', 'ComfortMessageSetting', 'CustomNumberInfo',
+           'CustomNumberType', 'CustomNumbers', 'DND', 'DefaultVoicemailPinRules', 'DialResponse', 'Dialing',
+           'DistinctiveRing', 'EnabledAndNumberOfDays', 'Event', 'ExecAssistantType', 'ExpirePasscode',
+           'ExternalCallerIdNamePolicy', 'ExternalTransfer', 'FailedAttempts', 'FeatureSelector', 'ForwardCallsTo',
+           'ForwardToSelection', 'ForwardingRule', 'ForwardingRuleDetails', 'ForwardingSetting', 'Greeting', 'Group',
+           'GroupMember', 'HGCallPolicies', 'HGandCQ', 'HistoryType', 'HuntGroup', 'IncomingPermissions',
+           'InterceptAnnouncements', 'InterceptNumber', 'InterceptSetting', 'InterceptSettingIncoming',
+           'InterceptSettingOutgoing', 'InterceptTypeIncoming', 'InterceptTypeOutgoing', 'License', 'Location',
+           'LocationAddress', 'LocationCallParkSettings', 'LocationMoHGreetingType', 'LocationMoHSetting',
+           'LocationVoiceMailSettings', 'MenuKey', 'MohMessageSetting', 'MonitoredElement', 'MonitoredElementMember',
+           'MonitoredMember', 'Monitoring', 'NetworkConnectionType', 'NoAnswer', 'Notification', 'NotificationRepeat',
+           'NotificationType', 'NumberDetails', 'NumberListPhoneNumber', 'NumberListPhoneNumberType',
+           'NumberLocation', 'NumberOwner', 'NumberState', 'NumberType', 'OrganisationVoicemailSettings',
+           'OrganisationVoicemailSettingsAPI', 'OutgoingPermissionCallType', 'OutgoingPermissions', 'OverflowAction',
+           'OverflowSetting', 'OwnerType', 'PTTConnectionType', 'Paging', 'PagingAgent', 'ParkedAgainst',
+           'PasscodeRules', 'PeopleStatus', 'Person', 'PersonForwardingSetting', 'PersonNumbers', 'PersonPhoneNumber',
+           'PersonPlaceAgent', 'PersonSettingsApiChild', 'PersonType', 'Personality', 'PhoneNumber',
+           'PhoneNumberType', 'PinLength', 'Policy', 'Privacy', 'PushToTalkAccessType', 'PushToTalkSettings',
+           'QueueSettings', 'Recall', 'RecallHuntGroup', 'ReceptionistSettings', 'Record', 'RecordingState',
+           'RecurWeekly', 'RecurYearlyByDate', 'RecurYearlyByDay', 'Recurrence', 'RedirectReason', 'Redirection',
+           'RejectAction', 'RingPattern', 'Schedule', 'ScheduleApiBase', 'ScheduleDay', 'ScheduleMonth',
+           'ScheduleType', 'ScheduleTypeOrStr', 'ScheduleWeek', 'SipAddress', 'SipType', 'SiteType', 'StorageType',
+           'StrOrDict', 'TelephonyCall', 'TelephonyEvent', 'TelephonyEventData', 'TelephonyParty', 'Tokens',
+           'UCMProfile', 'UnansweredCalls', 'UserBase', 'UserNumber', 'UserType', 'ValidateExtensionResponseStatus',
+           'ValidateExtensionStatus', 'ValidateExtensionStatusState', 'ValidateExtensionsResponse', 'VoiceMailFax',
+           'VoiceMailRules', 'VoicePortalSettings', 'VoicemailCopyOfMessage', 'VoicemailEnabled',
+           'VoicemailEnabledWithGreeting', 'VoicemailFax', 'VoicemailGroup', 'VoicemailMessageStorage',
+           'VoicemailNotifications', 'VoicemailSettings', 'VoicemailTransferToNumber', 'WaitMessageSetting',
+           'WaitMode', 'WebHook', 'WebHookCreate', 'WebHookEvent', 'WebHookResource', 'WebHookStatus',
+           'WelcomeMessageSetting', 'WorkSpaceType', 'Workspace', 'WorkspaceEmail', '_Helper', 'to_camel',
+           'webex_id_to_uuid']
